extern crate chrono;
extern crate feed_rs;
extern crate maud;
extern crate reqwest;

use std::error::Error;
use std::fs::write;
use std::fs::DirBuilder;
use std::path::Path;
use utilities::read_feed;

mod index_generator;
mod utilities;
mod web_fetchers;

fn main() -> Result<(), Box<dyn Error>> {
    simple_logger::init_with_level(log::Level::Info).unwrap();

    let featured = read_feed("featured_feeds.txt").first().unwrap().clone();
    let entries = read_feed("feeds.txt");

    log::info!(
        "Featured article: {}",
        entries[0].links.first().unwrap().href.as_str()
    );

    let index = index_generator::generate_index(entries, featured);

    let output_path = Path::new("output/index.html");
    DirBuilder::new()
        .recursive(true)
        .create(output_path.parent().unwrap())
        .unwrap();

    match write(output_path, index.into_string()) {
        Ok(_) => log::info!("Successfully wrote to {}", output_path.display()),
        Err(e) => log::error!("Failed to write to {}: {}", output_path.display(), e),
    }

    Ok(())
}
